@@ -17,7 +17,7 @@ NULL
 
 ## A fix to let CRAN check NOTEs diasappear for non-standard-evaluation used
 ## cf. http://stackoverflow.com/questions/9439256/how-can-i-handle-r-cmd-check-no-visible-binding-for-global-variable-notes-when
-globalVariables(c("one_of", "all_of", ".", "matches", "starts_with", "contains", # dplyr
+globalVariables(c("one_of", "all_of", ".", "matches", "starts_with", "contains", "id", "id_2", # dplyr
                   "manifesto_id", "country", "party", "edate", "per0", # general dataset
                   "md5sum_text.x", "md5sum_text.y", "code", "manifestos", "title", "translation_en", # & metadata & api download
                   "download", "url_original", "is_primary_doc", "originals", "annotations",
